Workflow
========
.. autofunction:: eliater.workflow

Add edges for conditional independences between D-separated nodes
-----------------------------------------------------------------
.. automodapi:: eliater.network_validation
    :no-heading:
    :include-all-objects:

Remove Nuisance Variables
-------------------------
.. automodapi:: eliater.discover_latent_nodes
    :no-heading:
    :include-all-objects:

Estimation with Linear Regression
---------------------------------
.. automodapi:: eliater.regression
    :no-heading:
    :include-all-objects:
